pub enum FieldEvaluationReason {
UnknownField,
UnresolvedBookmark,
UnsupportedSwitch,
NoComputedResult,
}Expand description
Reason a field’s computed value is not available.
Variants
UnknownField
rwml does not know this field instruction class yet.
UnresolvedBookmark
The field points at a bookmark/scope rwml could not resolve.
UnsupportedSwitch
The instruction contains a switch whose value can change the result.
NoComputedResult
The instruction is supported, but the document contains no computable value.