FloatingShape

Struct FloatingShape 

pub struct FloatingShape {
Show 23 fields pub id: String, pub name: Option<String>, pub description: Option<String>, pub text: Option<String>, pub preset_geometry: Option<String>, pub fill_color: Option<Color>, pub outline_color: Option<Color>, pub simple_position_enabled: Option<bool>, pub simple_position: Option<ShapePoint>, pub effect_extent: Option<ShapeEffectExtent>, pub anchor_block_index: Option<usize>, pub anchor_text: Option<String>, pub anchor_char_offset: Option<usize>, pub extent: Option<ShapeExtent>, pub horizontal_position: Option<ShapePosition>, pub vertical_position: Option<ShapePosition>, pub relative_height: Option<i64>, pub behind_doc: Option<bool>, pub layout_in_cell: Option<bool>, pub locked: Option<bool>, pub allow_overlap: Option<bool>, pub distance: ShapeDistance, pub wrapping: Option<ShapeWrapping>,
}
Floating shape geometry recovered from a Word document.

Fields

id: String

Stable shape id, normally the wp:docPr/@id value for .docx.

name: Option<String>

Display name from wp:docPr/@name, if present.

description: Option<String>

Alternative text/description from wp:docPr/@descr, if present.

text: Option<String>

Visible text recovered from a text-bearing shape body, when present.

preset_geometry: Option<String>

DrawingML preset geometry name from a:prstGeom/@prst, when present.

fill_color: Option<Color>

Simple DrawingML solid fill color from a:solidFill/a:srgbClr, when present.

outline_color: Option<Color>

Simple DrawingML outline color from a:ln/a:solidFill/a:srgbClr, when present.

simple_position_enabled: Option<bool>

Whether wp:anchor/@simplePos asks consumers to use wp:simplePos.

simple_position: Option<ShapePoint>

Absolute wp:simplePos point, when present.

effect_extent: Option<ShapeEffectExtent>

Visual-effect extents from wp:effectExtent, when present.

anchor_block_index: Option<usize>

Best-effort zero-based top-level body block index containing the anchor, when recoverable from .docx body order.

anchor_text: Option<String>

Best-effort visible text of the containing top-level body block, excluding the floating shape body itself when recovered from .docx.

anchor_char_offset: Option<usize>

Zero-width anchor offset inside anchor_text, counted in Unicode scalar values after the same text normalization used for anchor_text.

extent: Option<ShapeExtent>

Shape drawing extent in EMUs, if present.

horizontal_position: Option<ShapePosition>

Horizontal positioning metadata from wp:positionH, if present.

vertical_position: Option<ShapePosition>

Vertical positioning metadata from wp:positionV, if present.

relative_height: Option<i64>

WordprocessingML relativeHeight z-order value, when present.

behind_doc: Option<bool>

Whether the anchor asks Word to place the shape behind document text.

layout_in_cell: Option<bool>

Whether the anchor is laid out inside table cells.

locked: Option<bool>

Whether the anchor is locked.

allow_overlap: Option<bool>

Whether the anchor may overlap other floating objects.

distance: ShapeDistance

Text-distance margins declared by wp:anchor/@dist*.

wrapping: Option<ShapeWrapping>

Text-wrapping policy declared by the anchor, if present.